@@ -28,6 +28,7 @@
 #include <X11/X.h>
 #include <gdk/gdkx.h>
 #include <gtk/gtk.h>
+#include <X11/XF86keysym.h>
 
 #include <libhal-gmanager.h>
 #include <libhal-gdevice.h>
@@ -35,8 +36,7 @@
 
 #include "gpm-common.h"
 #include "gpm-button.h"
-#include "gpm-debug.h"
-#include "gpm-sound.h"
+#include "egg-debug.h"
 #include "gpm-marshal.h"
 
 static void     gpm_button_class_init (GpmButtonClass *klass);
@@ -49,8 +49,9 @@ struct GpmButtonPrivate
 {
 	GdkScreen		*screen;
 	GdkWindow		*window;
-	GpmSound		*sound;
-	GHashTable		*hash_to_hal;
+	GHashTable		*keysym_to_name_hash;
+	gchar			*last_button;
+	GTimer			*timer;
 	gboolean		 lid_is_closed;
 	HalGManager		*hal_manager; /* remove when input events is in the kernel */
 	HalGDevicestore		*hal_devicestore;
@@ -66,39 +67,67 @@ static gpointer gpm_button_object = NULL;
 
 G_DEFINE_TYPE (GpmButton, gpm_button, G_TYPE_OBJECT)
 
+#define GPM_BUTTON_DUPLICATE_TIMEOUT	0.25f
+
+/**
+ * gpm_button_emit_type:
+ **/
+gboolean
+gpm_button_emit_type (GpmButton *button, const gchar *type)
+{
+	g_return_val_if_fail (button != NULL, FALSE);
+	g_return_val_if_fail (GPM_IS_BUTTON (button), FALSE);
+
+	/* did we just have this button before the timeout? */
+	if (g_strcmp0 (type, button->priv->last_button) == 0 &&
+	    g_timer_elapsed (button->priv->timer, NULL) < GPM_BUTTON_DUPLICATE_TIMEOUT) {
+		egg_debug ("ignoring duplicate button %s", type);
+		return FALSE;
+	}
+
+	egg_debug ("emitting button-pressed : %s", type);
+	g_signal_emit (button, signals [BUTTON_PRESSED], 0, type);
+
+	/* save type and last size */
+	g_free (button->priv->last_button);
+	button->priv->last_button = g_strdup (type);
+	g_timer_reset (button->priv->timer);
+
+	return TRUE;
+}
+
+/**
+ * gpm_button_filter_x_events:
+ **/
 static GdkFilterReturn
-gpm_button_filter_x_events (GdkXEvent *xevent,
-			    GdkEvent  *event,
-			    gpointer   data)
+gpm_button_filter_x_events (GdkXEvent *xevent, GdkEvent *event, gpointer data)
 {
 	GpmButton *button = (GpmButton *) data;
 	XEvent *xev = (XEvent *) xevent;
-	guint keycode, state;
-	gchar *hashkey;
-	gchar *key;
+	guint keycode;
+	const gchar *key;
+	gchar *keycode_str;
 
-	if (xev->type != KeyPress) {
+	if (xev->type != KeyPress)
 		return GDK_FILTER_CONTINUE;
-	}
 
 	keycode = xev->xkey.keycode;
-	state = xev->xkey.state;
-
-	hashkey = g_strdup_printf ("key_%x_%x", state, keycode);
 
 	/* is the key string already in our DB? */
-	key = g_hash_table_lookup (button->priv->hash_to_hal, hashkey);
+	keycode_str = g_strdup_printf ("0x%x", keycode);
+	key = g_hash_table_lookup (button->priv->keysym_to_name_hash, (gpointer) keycode_str);
+	g_free (keycode_str);
+
+	/* found anything? */
 	if (key == NULL) {
-		gpm_debug ("Key '%s' not found in hash", hashkey);
+		egg_debug ("Key %i not found in hash", keycode);
 		/* pass normal keypresses on, which might help with accessibility access */
-		g_free (hashkey);
 		return GDK_FILTER_CONTINUE;
 	}
 
-	gpm_debug ("Key '%s' mapped to HAL key %s", hashkey, key);
-	g_signal_emit (button, signals [BUTTON_PRESSED], 0, key);
+	egg_debug ("Key %i mapped to key %s", keycode, key);
+	gpm_button_emit_type (button, key);
 
-	g_free (hashkey);
 	return GDK_FILTER_REMOVE;
 }
 
@@ -115,33 +144,15 @@ gpm_button_filter_x_events (GdkXEvent *xevent,
  * Return value: TRUE if we parsed and grabbed okay
  **/
 static gboolean
-gpm_button_grab_keystring (GpmButton   *button,
-			   const gchar *keystr,
-			   gchar      **hashkey)
+gpm_button_grab_keystring (GpmButton *button, guint64 keycode)
 {
 	guint modmask = 0;
-	KeySym keysym = 0;
-	KeyCode keycode = 0;
 	Display *display;
 	gint ret;
 
 	/* get the current X Display */
 	display = GDK_DISPLAY ();
 
-	keysym = XStringToKeysym (keystr);
-
-	/* no mask string, lets try find a keysym */
-	if (keysym == NoSymbol) {
-		gpm_debug ("'%s' not in XStringToKeysym", keystr);
-		return FALSE;
-	}
-
-	keycode = XKeysymToKeycode (display, keysym);
-	/* check we got a valid keycode */
-	if (keycode == 0) {
-		return FALSE;
-	}
-
 	/* don't abort on error */
 	gdk_error_trap_push ();
 
@@ -150,8 +161,8 @@ gpm_button_grab_keystring (GpmButton   *button,
 			GDK_WINDOW_XID (button->priv->window), True,
 			GrabModeAsync, GrabModeAsync);
 	if (ret == BadAccess) {
-		gpm_warning ("Failed to grab modmask=%u, keycode=%i",
-			     modmask, keycode);
+		egg_warning ("Failed to grab modmask=%u, keycode=%li",
+			     modmask, (long int) keycode);
 		return FALSE;
 	}
 
@@ -160,8 +171,8 @@ gpm_button_grab_keystring (GpmButton   *button,
 			GDK_WINDOW_XID (button->priv->window), True,
 			GrabModeAsync, GrabModeAsync);
 	if (ret == BadAccess) {
-		gpm_warning ("Failed to grab modmask=%u, keycode=%i",
-			     LockMask | modmask, keycode);
+		egg_warning ("Failed to grab modmask=%u, keycode=%li",
+			     LockMask | modmask, (long int) keycode);
 		return FALSE;
 	}
 
@@ -169,12 +180,7 @@ gpm_button_grab_keystring (GpmButton   *button,
 	gdk_flush ();
 	gdk_error_trap_pop ();
 
-	/* generate the unique hash */
-	if (hashkey) {
-		*hashkey = g_strdup_printf ("key_%x_%x", modmask, keycode);
-	}
-
-	gpm_debug ("Grabbed %s (+lock) modmask=%x, keycode=%x", keystr, modmask, keycode);
+	egg_debug ("Grabbed modmask=%x, keycode=%li", modmask, (long int) keycode);
 	return TRUE;
 }
 
@@ -191,29 +197,39 @@ gpm_button_grab_keystring (GpmButton   *button,
  * Return value: TRUE if we parsed and grabbed okay
  **/
 static gboolean
-gpm_button_button_key (GpmButton   *button,
-		       const gchar *keystr,
-		       const gchar *hal_key)
+gpm_button_xevent_key (GpmButton *button, guint keysym, const gchar *hal_key)
 {
-	char *key = NULL;
+	gchar *key = NULL;
 	gboolean ret;
+	gchar *keycode_str;
+	guint keycode;
+
+	/* convert from keysym to keycode */
+	keycode = XKeysymToKeycode (GDK_DISPLAY (), keysym);
+	if (keycode == 0) {
+		egg_warning ("could not map keysym %x to keycode", keysym);
+		return FALSE;
+	}
 
 	/* is the key string already in our DB? */
-	key = g_hash_table_lookup (button->priv->hash_to_hal, keystr);
+	keycode_str = g_strdup_printf ("0x%x", keycode);
+	key = g_hash_table_lookup (button->priv->keysym_to_name_hash, (gpointer) keycode_str);
 	if (key != NULL) {
-		gpm_warning ("Already buttoning %s", keystr);
+		egg_warning ("found in hash %i", keycode);
+		g_free (keycode_str);
 		return FALSE;
 	}
 
 	/* try to register X event */
-	ret = gpm_button_grab_keystring (button, keystr, &key);
-	if (ret == FALSE) {
-		gpm_warning ("Failed to grab %s", keystr);
+	ret = gpm_button_grab_keystring (button, keycode);
+	if (!ret) {
+		egg_warning ("Failed to grab %i", keycode);
+		g_free (keycode_str);
 		return FALSE;
 	}
 
 	/* add to hash table */
-	g_hash_table_insert (button->priv->hash_to_hal, key, (gpointer) hal_key);
+	g_hash_table_insert (button->priv->keysym_to_name_hash, (gpointer) keycode_str, (gpointer) g_strdup (hal_key));
 
 	/* the key is freed in the hash function unref */
 	return TRUE;
@@ -235,8 +251,7 @@ gpm_button_class_init (GpmButtonClass *klass)
 			      G_TYPE_FROM_CLASS (object_class),
 			      G_SIGNAL_RUN_LAST,
 			      G_STRUCT_OFFSET (GpmButtonClass, button_pressed),
-			      NULL,
-			      NULL,
+			      NULL, NULL,
 			      gpm_marshal_VOID__STRING,
 			      G_TYPE_NONE, 1, G_TYPE_STRING);
 }
@@ -269,25 +284,22 @@ gpm_button_is_lid_closed (GpmButton *button)
  *      button.type=""
  */
 static void
-emit_button_pressed (GpmButton   *button,
-		     HalGDevice  *device,
-		     const gchar *details)
+emit_button_pressed (GpmButton *button, HalGDevice *device, const gchar *details)
 {
 	gchar *type = NULL;
 	gboolean state;
-	const char *atype;
+	const gchar *atype;
 
 	g_return_if_fail (device != NULL);
 	g_return_if_fail (details != NULL);
 
 	if (strcmp (details, "") == 0) {
-		/* no details about the event, so we get more info
-		   for type 1 buttons */
+		/* no details about the event, so we get more info for type 1 buttons */
 		hal_gdevice_get_string (device, "button.type", &type, NULL);
 		/* hal may no longer be there */
 		if (type == NULL) {
-			gpm_warning ("cannot get button type for %s", hal_gdevice_get_udi (device));
-			return;
+			egg_warning ("cannot get button type for %s", hal_gdevice_get_udi (device));
+			goto out;
 		}
 	} else {
 		type = g_strdup (details);
@@ -297,44 +309,34 @@ emit_button_pressed (GpmButton   *button,
 	/* Buttons without state should default to true. */
 	state = TRUE;
 	/* we need to get the button state for lid buttons */
-	if (strcmp (type, "lid") == 0) {
+	if (strcmp (type, "lid") == 0)
 		hal_gdevice_get_bool (device, "button.state.value", &state, NULL);
-	}
 
 	/* abstact away that HAL has an extra parameter */
-	if (strcmp (type, GPM_BUTTON_LID_DEP) == 0 && state == FALSE) {
+	if (strcmp (type, GPM_BUTTON_LID_DEP) == 0 && state == FALSE)
 		atype = GPM_BUTTON_LID_OPEN;
-	} else if (strcmp (type, GPM_BUTTON_LID_DEP) == 0 && state == TRUE) {
+	else if (strcmp (type, GPM_BUTTON_LID_DEP) == 0 && state)
 		atype = GPM_BUTTON_LID_CLOSED;
-	}
 
 	/* filter out duplicate lid events */
 	if (strcmp (atype, GPM_BUTTON_LID_CLOSED) == 0) {
-		if (button->priv->lid_is_closed == TRUE) {
-			gpm_debug ("ignoring duplicate lid event");
+		if (button->priv->lid_is_closed) {
+			egg_debug ("ignoring duplicate lid event");
 			return;
 		}
 		button->priv->lid_is_closed = TRUE;
 	}
 	if (strcmp (atype, GPM_BUTTON_LID_OPEN) == 0) {
 		if (button->priv->lid_is_closed == FALSE) {
-			gpm_debug ("ignoring duplicate lid event");
+			egg_debug ("ignoring duplicate lid event");
 			return;
 		}
 		button->priv->lid_is_closed = FALSE;
 	}
 
-	/* the names changed in 0.5.8 */
-	if (strcmp (type, GPM_BUTTON_BRIGHT_UP_DEP) == 0) {
-		atype = GPM_BUTTON_BRIGHT_UP;
-	} else if (strcmp (type, GPM_BUTTON_BRIGHT_DOWN_DEP) == 0) {
-		atype = GPM_BUTTON_BRIGHT_DOWN;
-	}
-
-	/* we now emit all buttons, even the ones we don't know */
-	gpm_debug ("emitting button-pressed : %s", atype);
-	g_signal_emit (button, signals [BUTTON_PRESSED], 0, atype);
-
+	/* we emit all buttons, even the ones we don't know */
+	gpm_button_emit_type (button, atype);
+out:
 	g_free (type);
 }
 
@@ -357,17 +359,16 @@ hal_device_property_modified_cb (HalGDevice    *device,
 				 gboolean       finally,
 				 GpmButton     *button)
 {
-	gpm_debug ("key=%s, added=%i, removed=%i, finally=%i",
+	egg_debug ("key=%s, added=%i, removed=%i, finally=%i",
 		   key, is_added, is_removed, finally);
 
 	/* do not process keys that have been removed */
-	if (is_removed == TRUE) {
+	if (is_removed)
 		return;
-	}
 
 	/* only match button* values */
 	if (strncmp (key, "button", 6) == 0) {
-		gpm_debug ("state of a button has changed : %s, %s", hal_gdevice_get_udi (device), key);
+		egg_debug ("state of a button has changed : %s, %s", hal_gdevice_get_udi (device), key);
 		emit_button_pressed (button, device, "");
 	}
 }
@@ -388,11 +389,10 @@ hal_device_condition_cb (HalGDevice    *device,
 			 const gchar   *details,
 			 GpmButton     *button)
 {
-	gpm_debug ("condition=%s, details=%s", condition, details);
+	egg_debug ("condition=%s, details=%s", condition, details);
 
-	if (strcmp (condition, "ButtonPressed") == 0) {
+	if (strcmp (condition, "ButtonPressed") == 0)
 		emit_button_pressed (button, device, details);
-	}
 }
 
 /**
@@ -434,8 +434,8 @@ coldplug_buttons (GpmButton *button)
 	/* devices of type button */
 	error = NULL;
 	ret = hal_gmanager_find_capability (button->priv->hal_manager, "button", &device_names, &error);
-	if (ret == FALSE) {
-		gpm_warning ("Couldn't obtain list of buttons: %s", error->message);
+	if (!ret) {
+		egg_warning ("Couldn't obtain list of buttons: %s", error->message);
 		g_error_free (error);
 		return;
 	}
@@ -443,10 +443,10 @@ coldplug_buttons (GpmButton *button)
 		/* we have found buttons */
 		for (i = 0; device_names[i]; i++) {
 			watch_add_button (button, device_names[i]);
-			gpm_debug ("Watching %s", device_names[i]);
+			egg_debug ("Watching %s", device_names[i]);
 		}
 	} else {
-		gpm_debug ("Couldn't obtain list of buttons");
+		egg_debug ("Couldn't obtain list of buttons");
 	}
 
 	hal_gmanager_free_capability (device_names);
@@ -494,29 +494,29 @@ gpm_button_init (GpmButton *button)
 	button->priv->screen = gdk_screen_get_default ();
 	button->priv->window = gdk_screen_get_root_window (button->priv->screen);
 
-	button->priv->hash_to_hal = g_hash_table_new_full (g_str_hash, g_str_equal, g_free, NULL);
+	button->priv->keysym_to_name_hash = g_hash_table_new_full (g_str_hash, g_str_equal, g_free, g_free);
+	button->priv->last_button = NULL;
+	button->priv->timer = g_timer_new ();
 
 	button->priv->lid_is_closed = FALSE;
-	button->priv->sound = gpm_sound_new ();
 
 #ifdef HAVE_XEVENTS
 	have_xevents = TRUE;
 #endif
 
-	if (have_xevents == TRUE) {
+	if (have_xevents) {
 		/* register the brightness keys */
-		gpm_button_button_key (button, "XF86XK_Execute", GPM_BUTTON_POWER);
-		gpm_button_button_key (button, "XF86XK_PowerOff", GPM_BUTTON_POWER);
-		gpm_button_button_key (button, "XF86XK_Suspend", GPM_BUTTON_SUSPEND);
-		gpm_button_button_key (button, "XF86XK_Sleep", GPM_BUTTON_SUSPEND); /* should be configurable */
-		gpm_button_button_key (button, "XF86XK_Hibernate", GPM_BUTTON_HIBERNATE);
-		gpm_button_button_key (button, "XF86BrightnessUp", GPM_BUTTON_BRIGHT_UP);
-		gpm_button_button_key (button, "XF86BrightnessDown", GPM_BUTTON_BRIGHT_DOWN);
-		gpm_button_button_key (button, "XF86XK_ScreenSaver", GPM_BUTTON_LOCK);
-		gpm_button_button_key (button, "XF86XK_Battery", GPM_BUTTON_BATTERY);
-		gpm_button_button_key (button, "XF86KeyboardLightUp", GPM_BUTTON_KBD_BRIGHT_UP);
-		gpm_button_button_key (button, "XF86KeyboardLightDown", GPM_BUTTON_KBD_BRIGHT_DOWN);
-		gpm_button_button_key (button, "XF86KeyboardLightOnOff", GPM_BUTTON_KBD_BRIGHT_TOGGLE);
+		gpm_button_xevent_key (button, XF86XK_PowerOff, GPM_BUTTON_POWER);
+//		gpm_button_xevent_key (button, XF86XK_Suspend, GPM_BUTTON_SUSPEND);
+		gpm_button_xevent_key (button, XF86XK_Sleep, GPM_BUTTON_SUSPEND); /* should be configurable */
+//		gpm_button_xevent_key (button, XF86XK_Hibernate, GPM_BUTTON_HIBERNATE);
+		gpm_button_xevent_key (button, XF86XK_MonBrightnessUp, GPM_BUTTON_BRIGHT_UP);
+		gpm_button_xevent_key (button, XF86XK_MonBrightnessDown, GPM_BUTTON_BRIGHT_DOWN);
+		gpm_button_xevent_key (button, XF86XK_ScreenSaver, GPM_BUTTON_LOCK);
+//		gpm_button_xevent_key (button, XF86XK_Battery, GPM_BUTTON_BATTERY);
+		gpm_button_xevent_key (button, XF86XK_KbdBrightnessUp, GPM_BUTTON_KBD_BRIGHT_UP);
+		gpm_button_xevent_key (button, XF86XK_KbdBrightnessDown, GPM_BUTTON_KBD_BRIGHT_DOWN);
+		gpm_button_xevent_key (button, XF86XK_KbdLightOnOff, GPM_BUTTON_KBD_BRIGHT_TOGGLE);
 
 		/* use global filter */
 		gdk_window_add_filter (button->priv->window,
@@ -551,9 +551,10 @@ gpm_button_finalize (GObject *object)
 
 	g_object_unref (button->priv->hal_manager);
 	g_object_unref (button->priv->hal_devicestore);
-	g_object_unref (button->priv->sound);
+	g_free (button->priv->last_button);
+	g_timer_destroy (button->priv->timer);
 
-	g_hash_table_unref (button->priv->hash_to_hal);
+	g_hash_table_unref (button->priv->keysym_to_name_hash);
 
 	G_OBJECT_CLASS (gpm_button_parent_class)->finalize (object);
 }
